@@ -9,8 +9,8 @@ class TokenProvider:
         url: URL a la que se enviará la petición para obtener el token.
     """
 
-    def __init__(self, url):
-        self.url = url
+    def __init__(self, url_token_provider):
+        self.url_token_provider = url_token_provider
         self.token = None
 
     def _solicitar_nuevo_token(self, *, data=None, files=None):
@@ -24,7 +24,7 @@ class TokenProvider:
         Retorna:
             dict: La respuesta del servidor como objeto JSON.
         """
-        response = requests.post(self.url, data=data, files=files)
+        response = requests.post(self.url_token_provider, data=data, files=files)
         response.raise_for_status()
         return response.json()
 
